#import "CDVCustomKeyboard.h"

#define kScreenWidth [UIScreen mainScreen].bounds.size.width
#define kScreenHeight [UIScreen mainScreen].bounds.size.height
@interface CDVCustomKeyboard ()<UITextViewDelegate>

@property (nonatomic, readwrite, assign) BOOL keyboardIsVisible;
@property (nonatomic,strong)UITextView *hiddenTextView;
@property (nonatomic,strong)UIView *backGroundView;
@property (nonatomic,strong)UIButton *clearButton;

@end

@implementation CDVCustomKeyboard

- (void)pluginInitialize
{
  CGFloat viewWidth=kScreenWidth;
  CGFloat viewHeight=40;
  CGFloat paddingTopBottom=5;
  CGFloat paddingLeftRight=3;

  if(self.backGroundView == NULL){
    self.backGroundView = [UIView new];
    self.backGroundView.alpha = 0;
    self.backGroundView.backgroundColor = [UIColor lightGrayColor];
    self.backGroundView.frame=CGRectMake(0,0,viewWidth,viewHeight);
    [self.viewController.view addSubview:self.backGroundView];
  }
    if (self.hiddenTextView == NULL) {

        self.hiddenTextView = [[UITextView alloc] init];
        self.hiddenTextView.alpha = 0;
        self.hiddenTextView.autocorrectionType = UITextAutocorrectionTypeNo;
        self.hiddenTextView.frame = CGRectMake(paddingLeftRight, paddingTopBottom, viewWidth-paddingLeftRight*2, viewHeight-paddingTopBottom*2);
        self.hiddenTextView.font = [UIFont fontWithName:@"Helvetica" size:17];
        // 设置文本框背景颜色
        self.hiddenTextView.backgroundColor = [UIColor whiteColor];
        //外框
        self.hiddenTextView.layer.borderColor = [UIColor grayColor].CGColor;
        self.hiddenTextView.layer.borderWidth = 1;
        self.hiddenTextView.layer.cornerRadius = 5;
        self.hiddenTextView.secureTextEntry = YES;
        self.hiddenTextView.delegate = self;

        //边距
        self.hiddenTextView.textContainerInset = UIEdgeInsetsMake(5, 0, 0, 35);
        [self.backGroundView addSubview:self.hiddenTextView];

        //clear button
        int kClearButtonWidth = 30;
        int kClearButtonHeight = kClearButtonWidth;

        //add the clear button
        self.clearButton = [UIButton buttonWithType:UIButtonTypeCustom];
        [self.clearButton setImage:[UIImage imageNamed:@"UITextFieldClearButton.png"] forState:UIControlStateNormal];
        [self.clearButton setImage:[UIImage imageNamed:@"UITextFieldClearButtonPressed.png"] forState:UIControlStateHighlighted];
        self.clearButton.alpha = 0;
        self.clearButton.imageEdgeInsets = UIEdgeInsetsMake(5, 5, 5, 5);
        self.clearButton.frame = CGRectMake(0, 0, kClearButtonWidth, kClearButtonHeight);
        self.clearButton.center = CGPointMake(kScreenWidth - kClearButtonWidth , kClearButtonHeight/2);
        self.clearButton.contentEdgeInsets = UIEdgeInsetsMake(0, 0, 0, 0);


        [self.clearButton addTarget:self action:@selector(clearTextView:) forControlEvents:UIControlEventTouchUpInside];

        [self.hiddenTextView addSubview:self.clearButton];
    }
         // 增加监听，当键盘出现或改变时收出消息
         [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(keyboardDidShow:)name:UIKeyboardDidShowNotification object:nil];
         // 增加监听，当键盘退出时收出消息
         [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(keyboardDidHide:)name:UIKeyboardDidHideNotification object:nil];

}

// 当键盘出现或改变时调用
 - (void)keyboardDidShow:(NSNotification *)aNotification{
    self.hiddenTextView.secureTextEntry = NO;
}
// 当键盘出现或改变时调用
 - (void)keyboardDidHide:(NSNotification *)aNotification{
   self.hiddenTextView.secureTextEntry = YES;
}

- (void)clearTextView:(id)sender{
    self.hiddenTextView.text = @"";
    self.clearButton.alpha = 0;
    CDVPluginResult* pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK messageAsString: self.hiddenTextView.text];
    [pluginResult setKeepCallbackAsBool:YES];
    [self.commandDelegate sendPluginResult:pluginResult  callbackId:self.callbackId];
}

- (void)textViewDidChange:(UITextView *)textView {
    NSString *text = textView.text;
    if([text isEqualToString:@""]){
        self.clearButton.alpha = 0;
    }else{
        self.clearButton.alpha = 1;
    }
    CDVPluginResult* pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK messageAsString:text];
    [pluginResult setKeepCallbackAsBool:YES];
    [self.commandDelegate sendPluginResult:pluginResult  callbackId:self.callbackId];
}

- (void) textViewDidEndEditing:(UITextView *)textView {
    [self displayInputView:NO];
    NSString *text = textView.text;
    CDVPluginResult* pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_ERROR messageAsString:text];
    [self.commandDelegate sendPluginResult:pluginResult  callbackId:self.callbackId];
}

- (void)open:(CDVInvokedUrlCommand*)command
{
    [self displayInputView:YES];
    self.callbackId = command.callbackId;
    NSString *startedValue = [command argumentAtIndex:0];
    NSInteger keyBoardTypeInt = [[command argumentAtIndex:1] integerValue];

    switch (keyBoardTypeInt) {
        case 1:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeDefault;                // Default type for the current input method.
            break;
        case 2:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeASCIICapable;                // Default type for the current input method.
            break;
        case 3:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeNumbersAndPunctuation;                // Default type for the current input method.
            break;
        case 4:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeURL;                // Default type for the current input method.
            break;
        case 5:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeNumberPad;                // Default type for the current input method.
            break;
        case 6:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypePhonePad;                // Default type for the current input method.
            break;
        case 7:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeNamePhonePad;                // Default type for the current input method.
            break;
        case 8:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeEmailAddress;                // Default type for the current input method.
            break;
        case 9:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeDecimalPad;                // Default type for the current input method.
            break;
        case 10:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeTwitter;                // Default type for the current input method.
            break;
        case 11:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeWebSearch;                // Default type for the current input method.
            break;
        case 12:
            self.hiddenTextView.secureTextEntry = NO;
            self.keyboardType =  UIKeyboardTypeAlphabet;
            break;
        case 13:
            self.hiddenTextView.secureTextEntry = YES;
            self.keyboardType =  UIKeyboardTypeAlphabet;
            break;
        default:
            self.keyboardType =  keyBoardTypeInt;
            break;
    }
    self.hiddenTextView.keyboardType = self.keyboardType;
    self.hiddenTextView.text = startedValue;
    if([startedValue isEqualToString:@""]){
        self.clearButton.alpha = 0;
    }else{
        self.clearButton.alpha = 1;
    }
    [self.hiddenTextView becomeFirstResponder];
}

- (void)close:(CDVInvokedUrlCommand*)command
{
    [self.webView becomeFirstResponder];
    [self.hiddenTextView resignFirstResponder];
    [self.commandDelegate sendPluginResult:[CDVPluginResult resultWithStatus:CDVCommandStatus_OK]  callbackId:command.callbackId];
}

- (void)change:(CDVInvokedUrlCommand*)command
{
    NSString *value = [command argumentAtIndex:0];
    self.hiddenTextView.text = value;
    CDVPluginResult* pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK];
    [self.commandDelegate sendPluginResult:pluginResult callbackId:command.callbackId];
}
- (BOOL)textView :(UITextView *)textView shouldChangeTextInRange :(NSRange)range replacementText :( NSString *)text{
    // need to escape these to be able to pass to the webview
  if ([text isEqualToString :@"\n"]) {
      // send event to JS
      // [self.commandDelegate sendPluginResult :P luginResult callbackId:callbackId];
    [self.hiddenTextView resignFirstResponder];
    return NO;
    // ignore the 'tab' character
  } else if ([text isEqualToString :@"\t"]) {
    [self.hiddenTextView resignFirstResponder];
    return NO;
  }
  return YES;
};

-(void)displayInputView:(BOOL)display
{
    if(display){
      self.hiddenTextView.alpha=1;
      self.backGroundView.alpha=1;
    }else{
      self.hiddenTextView.alpha=0;
      self.backGroundView.alpha=0;
    }
}

@end